@@ -1,18 +1,55 @@
-#[doc = "Reader of register CFSR"]
-pub type R = crate::R<u32, super::CFSR>;
-#[doc = "Writer for register CFSR"]
-pub type W = crate::W<u32, super::CFSR>;
-#[doc = "Register CFSR `reset()`'s with value 0"]
-impl crate::ResetValue for super::CFSR {
-    type Type = u32;
+#[doc = "Register `CFSR` reader"]
+pub struct R(crate::R<CFSR_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<CFSR_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `IACCVIOL`"]
-pub type IACCVIOL_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `IACCVIOL`"]
+impl From<crate::R<CFSR_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<CFSR_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `CFSR` writer"]
+pub struct W(crate::W<CFSR_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<CFSR_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<CFSR_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<CFSR_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `IACCVIOL` reader - Instruction access violation"]
+pub struct IACCVIOL_R(crate::FieldReader<bool, bool>);
+impl IACCVIOL_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IACCVIOL_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for IACCVIOL_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IACCVIOL` writer - Instruction access violation"]
 pub struct IACCVIOL_W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +67,26 @@ impl<'a> IACCVIOL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
-#[doc = "Reader of field `DACCVIOL`"]
-pub type DACCVIOL_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `DACCVIOL`"]
+#[doc = "Field `DACCVIOL` reader - Data access violation"]
+pub struct DACCVIOL_R(crate::FieldReader<bool, bool>);
+impl DACCVIOL_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        DACCVIOL_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for DACCVIOL_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DACCVIOL` writer - Data access violation"]
 pub struct DACCVIOL_W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +104,26 @@ impl<'a> DACCVIOL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `MUNSTKERR`"]
-pub type MUNSTKERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `MUNSTKERR`"]
+#[doc = "Field `MUNSTKERR` reader - MemManage Fault on unstacking for exception return"]
+pub struct MUNSTKERR_R(crate::FieldReader<bool, bool>);
+impl MUNSTKERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        MUNSTKERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for MUNSTKERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MUNSTKERR` writer - MemManage Fault on unstacking for exception return"]
 pub struct MUNSTKERR_W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +141,26 @@ impl<'a> MUNSTKERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
-#[doc = "Reader of field `MSTKERR`"]
-pub type MSTKERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `MSTKERR`"]
+#[doc = "Field `MSTKERR` reader - MemManage Fault on stacking for exception entry"]
+pub struct MSTKERR_R(crate::FieldReader<bool, bool>);
+impl MSTKERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        MSTKERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for MSTKERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MSTKERR` writer - MemManage Fault on stacking for exception entry"]
 pub struct MSTKERR_W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +178,26 @@ impl<'a> MSTKERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
-#[doc = "Reader of field `MLSPERR`"]
-pub type MLSPERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `MLSPERR`"]
+#[doc = "Field `MLSPERR` reader - MemManager Fault occured during FP lazy state preservation"]
+pub struct MLSPERR_R(crate::FieldReader<bool, bool>);
+impl MLSPERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        MLSPERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for MLSPERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MLSPERR` writer - MemManager Fault occured during FP lazy state preservation"]
 pub struct MLSPERR_W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +215,26 @@ impl<'a> MLSPERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
-#[doc = "Reader of field `MMARVALID`"]
-pub type MMARVALID_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `MMARVALID`"]
+#[doc = "Field `MMARVALID` reader - MemManage Fault Address Register valid"]
+pub struct MMARVALID_R(crate::FieldReader<bool, bool>);
+impl MMARVALID_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        MMARVALID_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for MMARVALID_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MMARVALID` writer - MemManage Fault Address Register valid"]
 pub struct MMARVALID_W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +252,26 @@ impl<'a> MMARVALID_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `IBUSERR`"]
-pub type IBUSERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `IBUSERR`"]
+#[doc = "Field `IBUSERR` reader - Instruction bus error"]
+pub struct IBUSERR_R(crate::FieldReader<bool, bool>);
+impl IBUSERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IBUSERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for IBUSERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IBUSERR` writer - Instruction bus error"]
 pub struct IBUSERR_W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +289,26 @@ impl<'a> IBUSERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `PRECISERR`"]
-pub type PRECISERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `PRECISERR`"]
+#[doc = "Field `PRECISERR` reader - Precise data bus error"]
+pub struct PRECISERR_R(crate::FieldReader<bool, bool>);
+impl PRECISERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        PRECISERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for PRECISERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PRECISERR` writer - Precise data bus error"]
 pub struct PRECISERR_W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +326,26 @@ impl<'a> PRECISERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `IMPRECISERR`"]
-pub type IMPRECISERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `IMPRECISERR`"]
+#[doc = "Field `IMPRECISERR` reader - Imprecise data bus error"]
+pub struct IMPRECISERR_R(crate::FieldReader<bool, bool>);
+impl IMPRECISERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IMPRECISERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for IMPRECISERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IMPRECISERR` writer - Imprecise data bus error"]
 pub struct IMPRECISERR_W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +363,26 @@ impl<'a> IMPRECISERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `UNSTKERR`"]
-pub type UNSTKERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `UNSTKERR`"]
+#[doc = "Field `UNSTKERR` reader - BusFault on unstacking for exception return"]
+pub struct UNSTKERR_R(crate::FieldReader<bool, bool>);
+impl UNSTKERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        UNSTKERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for UNSTKERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `UNSTKERR` writer - BusFault on unstacking for exception return"]
 pub struct UNSTKERR_W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +400,26 @@ impl<'a> UNSTKERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `STKERR`"]
-pub type STKERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `STKERR`"]
+#[doc = "Field `STKERR` reader - BusFault on stacking for exception entry"]
+pub struct STKERR_R(crate::FieldReader<bool, bool>);
+impl STKERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        STKERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for STKERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `STKERR` writer - BusFault on stacking for exception entry"]
 pub struct STKERR_W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +437,26 @@ impl<'a> STKERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `LSPERR`"]
-pub type LSPERR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `LSPERR`"]
+#[doc = "Field `LSPERR` reader - BusFault occured during FP lazy state preservation"]
+pub struct LSPERR_R(crate::FieldReader<bool, bool>);
+impl LSPERR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LSPERR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for LSPERR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LSPERR` writer - BusFault occured during FP lazy state preservation"]
 pub struct LSPERR_W<'a> {
     w: &'a mut W,
 }
@@ -294,13 +474,26 @@ impl<'a> LSPERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `BFARVALID`"]
-pub type BFARVALID_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `BFARVALID`"]
+#[doc = "Field `BFARVALID` reader - BusFault Address Register valid"]
+pub struct BFARVALID_R(crate::FieldReader<bool, bool>);
+impl BFARVALID_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        BFARVALID_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for BFARVALID_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `BFARVALID` writer - BusFault Address Register valid"]
 pub struct BFARVALID_W<'a> {
     w: &'a mut W,
 }
@@ -318,13 +511,26 @@ impl<'a> BFARVALID_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
-#[doc = "Reader of field `UNDEFINSTR`"]
-pub type UNDEFINSTR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `UNDEFINSTR`"]
+#[doc = "Field `UNDEFINSTR` reader - Undefined instruction UsageFault"]
+pub struct UNDEFINSTR_R(crate::FieldReader<bool, bool>);
+impl UNDEFINSTR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        UNDEFINSTR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for UNDEFINSTR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `UNDEFINSTR` writer - Undefined instruction UsageFault"]
 pub struct UNDEFINSTR_W<'a> {
     w: &'a mut W,
 }
@@ -342,13 +548,26 @@ impl<'a> UNDEFINSTR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
-#[doc = "Reader of field `INVSTATE`"]
-pub type INVSTATE_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVSTATE`"]
+#[doc = "Field `INVSTATE` reader - Invalid state UsageFault"]
+pub struct INVSTATE_R(crate::FieldReader<bool, bool>);
+impl INVSTATE_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVSTATE_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVSTATE_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVSTATE` writer - Invalid state UsageFault"]
 pub struct INVSTATE_W<'a> {
     w: &'a mut W,
 }
@@ -366,13 +585,26 @@ impl<'a> INVSTATE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
-#[doc = "Reader of field `INVPC`"]
-pub type INVPC_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INVPC`"]
+#[doc = "Field `INVPC` reader - Invalid PC load UsageFault"]
+pub struct INVPC_R(crate::FieldReader<bool, bool>);
+impl INVPC_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INVPC_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INVPC_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INVPC` writer - Invalid PC load UsageFault"]
 pub struct INVPC_W<'a> {
     w: &'a mut W,
 }
@@ -390,13 +622,26 @@ impl<'a> INVPC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
-#[doc = "Reader of field `NOCP`"]
-pub type NOCP_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `NOCP`"]
+#[doc = "Field `NOCP` reader - No coprocessor UsageFault"]
+pub struct NOCP_R(crate::FieldReader<bool, bool>);
+impl NOCP_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NOCP_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for NOCP_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NOCP` writer - No coprocessor UsageFault"]
 pub struct NOCP_W<'a> {
     w: &'a mut W,
 }
@@ -414,13 +659,26 @@ impl<'a> NOCP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
-#[doc = "Reader of field `UNALIGNED`"]
-pub type UNALIGNED_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `UNALIGNED`"]
+#[doc = "Field `UNALIGNED` reader - Unaligned access UsageFault"]
+pub struct UNALIGNED_R(crate::FieldReader<bool, bool>);
+impl UNALIGNED_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        UNALIGNED_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for UNALIGNED_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `UNALIGNED` writer - Unaligned access UsageFault"]
 pub struct UNALIGNED_W<'a> {
     w: &'a mut W,
 }
@@ -438,13 +696,26 @@ impl<'a> UNALIGNED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | (((value as u32) & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
         self.w
     }
 }
-#[doc = "Reader of field `DIVBYZERO`"]
-pub type DIVBYZERO_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `DIVBYZERO`"]
+#[doc = "Field `DIVBYZERO` reader - Divide by zero UsageFault"]
+pub struct DIVBYZERO_R(crate::FieldReader<bool, bool>);
+impl DIVBYZERO_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        DIVBYZERO_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for DIVBYZERO_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DIVBYZERO` writer - Divide by zero UsageFault"]
 pub struct DIVBYZERO_W<'a> {
     w: &'a mut W,
 }
@@ -462,7 +733,7 @@ impl<'a> DIVBYZERO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | (((value as u32) & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
         self.w
     }
 }
@@ -659,4 +930,30 @@ impl W {
     pub fn divbyzero(&mut self) -> DIVBYZERO_W {
         DIVBYZERO_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Configurable Fault Status Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cfsr](index.html) module"]
+pub struct CFSR_SPEC;
+impl crate::RegisterSpec for CFSR_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [cfsr::R](R) reader structure"]
+impl crate::Readable for CFSR_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [cfsr::W](W) writer structure"]
+impl crate::Writable for CFSR_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets CFSR to value 0"]
+impl crate::Resettable for CFSR_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
